#include <pch.h>

void Callbacks::GLFWError(int code, const char* message) {
    std::cout << std::format("GLFW Error: {}", message) << std::endl;
}

void Callbacks::OpenGLMessage(GLenum source, GLenum type, GLuint id, GLenum severity, GLsizei length,
    GLchar const* message, void const* user_param) {
    const char* source_string;
    switch(source) {
    case GL_DEBUG_SOURCE_API:
        source_string = "API";
        break;
    case GL_DEBUG_SOURCE_WINDOW_SYSTEM:
        source_string = "WINDOW SYSTEM";
        break;
    case GL_DEBUG_SOURCE_SHADER_COMPILER:
        source_string = "SHADER COMPILER";
        break;
    case GL_DEBUG_SOURCE_THIRD_PARTY:
        source_string = "THIRD PARTY";
        break;
    case GL_DEBUG_SOURCE_APPLICATION:
        source_string = "APPLICATION";
        break;
    case GL_DEBUG_SOURCE_OTHER:
        source_string = "OTHER";
        break;
    }

    const char* type_string;
    switch(type) {
    case GL_DEBUG_TYPE_ERROR:
        type_string = "ERROR";
        break;
    case GL_DEBUG_TYPE_DEPRECATED_BEHAVIOR:
        type_string = "DEPRECATED_BEHAVIOR";
        break;
    case GL_DEBUG_TYPE_UNDEFINED_BEHAVIOR:
        type_string = "UNDEFINED_BEHAVIOR";
        break;
    case GL_DEBUG_TYPE_PORTABILITY:
        type_string = "PORTABILITY";
        break;
    case GL_DEBUG_TYPE_PERFORMANCE:
        type_string = "PERFORMANCE";
        break;
    case GL_DEBUG_TYPE_MARKER:
        type_string = "MARKER";
        break;
    case GL_DEBUG_TYPE_OTHER:
        type_string = "OTHER";
        break;
    }

    const char* severity_string;
    switch(severity) {
    case GL_DEBUG_SEVERITY_NOTIFICATION:
        severity_string = "NOTIFICATION";
        break;
    case GL_DEBUG_SEVERITY_LOW:
        severity_string = "LOW";
        break;
    case GL_DEBUG_SEVERITY_MEDIUM:
        severity_string = "MEDIUM";
        break;
    case GL_DEBUG_SEVERITY_HIGH:
        severity_string = "HIGH";
        break;
    }

    std::cout << std::format("OpenGL: {}", type_string) << std::endl;
}
